==> RsSmw-4.90.49.49-py3-none-any.whl: RsSmw/Implementations/Source/Bb/Wlnn/Fblock/Logging.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Logging:
	"""Logging commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("logging", core, parent)

	def set(self, logging_state: bool, frameBlock=repcap.FrameBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:LOGGing \n
		Snippet: driver.source.bb.wlnn.fblock.logging.set(logging_state = False, frameBlock = repcap.FrameBlock.Default) \n
		If enabled (ON) , the contents of HE-SIG-A and HE-SIG-B fields are written to a file in a text form. The location of the
		file can be queried with [:SOURce<hw>]:BB:WLNN:FBLock<ch>:LOGGing. \n
			:param logging_state: 0| 1| OFF| ON
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')"""
		param = Conversions.bool_to_str(logging_state)
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:LOGGing {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:LOGGing \n
		Snippet: value: bool = driver.source.bb.wlnn.fblock.logging.get(frameBlock = repcap.FrameBlock.Default) \n
		If enabled (ON) , the contents of HE-SIG-A and HE-SIG-B fields are written to a file in a text form. The location of the
		file can be queried with [:SOURce<hw>]:BB:WLNN:FBLock<ch>:LOGGing. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:return: logging_state: 0| 1| OFF| ON"""
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:LOGGing?')
		return Conversions.str_to_bool(response)

==> RsSmw-4.90.49.53-py3-none-any.whl: RsSmw/Implementations/Source/Bb/Wlnn/Fblock/Logging.py <==
from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Logging:
	"""Logging commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("logging", core, parent)

	def set(self, logging_state: bool, frameBlock=repcap.FrameBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:LOGGing \n
		Snippet: driver.source.bb.wlnn.fblock.logging.set(logging_state = False, frameBlock = repcap.FrameBlock.Default) \n
		If enabled (ON) , the contents of HE-SIG-A and HE-SIG-B fields are written to a file in a text form. The location of the
		file can be queried with [:SOURce<hw>]:BB:WLNN:FBLock<ch>:LOGGing. \n
			:param logging_state: 0| 1| OFF| ON
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
		"""
		param = Conversions.bool_to_str(logging_state)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:LOGGing {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:LOGGing \n
		Snippet: value: bool = driver.source.bb.wlnn.fblock.logging.get(frameBlock = repcap.FrameBlock.Default) \n
		If enabled (ON) , the contents of HE-SIG-A and HE-SIG-B fields are written to a file in a text form. The location of the
		file can be queried with [:SOURce<hw>]:BB:WLNN:FBLock<ch>:LOGGing. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:return: logging_state: 0| 1| OFF| ON"""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:LOGGing?')
		return Conversions.str_to_bool(response)
